/*---------------------------------------------------------------------------*/
/*                   Headerfile fr HIGHEDIT Text-Editor                     */
/*                                                                           */
/*   Name:  highedit.h                                                       */
/*   Autor: Andreas Claus                                                    */
/*   Datum: 01.01.90                                                         */
/*                                                                           */
/*---------------------------------------------------------------------------*/

#ifndef _INC_HE100
#define _INC_HE100		// #defined if he100.h has been included

#ifdef __cplusplus
extern "C" {
#endif  // __cplusplus

#define WS_DEFHIGHEDIT (WS_CHILD | WS_VISIBLE | WS_CLIPCHILDREN | HS_PROFILE)

#define CLASS_HIGHEDIT "HighEdit"

/*----------------*/
/* Highedit Style */
/*----------------*/

#define HS_DIALOG         0x0000000010  /* Weniger Speicherverbrauch         */
#define HS_AUTOHSIZE      0x0000000040  /* Fensterbreite wird angeglichen    */
#define HS_PROFILE        0x0000000080  /* Standarteinstellungen werden beim */
                                        /* Start aus HIGHEDIT.INI gelesen    */
#define HS_NOTIFY         0x0000000100  /* Fr Visual Basic:                 */
                                        /* HEM-Nachrichten bei Tasten- und   */
                                        /* Mausaktionen werden an das        */
                                        /* Elternfenster gesendet            */

#define HS_UNDO 		  0x0000000200	/* UNDO-Funktion aktiviert			 */
#define HS_HEADFOOT       0x0000000800  /* Fenster fr Kopf- Fuzeilen       */
                                        /* Integriert                        */

/*------------------*/
/* Aktiver HighEdit */
/*------------------*/

#define CONTEXT_MAIN 0
#define CONTEXT_HEAD 1
#define CONTEXT_FOOT 2

/*-------------*/
/* Dateiffnen */
/*-------------*/

#define OF_APPEND 4     /* Anfgen an eine bestehende Datei */

#define OF_DEFHESAVE (OF_CREATE | OF_READWRITE | OF_SHARE_DENY_NONE)

/*------------*/
/* Undo Typen */
/*------------*/

#define UNDO_NONE -1
#define UNDO_CHARINSERT 0
#define UNDO_CHARDELETE 1
#define UNDO_LINEINSERT 2
#define UNDO_BACKSPACE	3
#define UNDO_LINEDELETE 4
#define UNDO_BLOCKCUT	5
#define UNDO_BLOCKPASTE 6
#define UNDO_BLOCKCLEAR 7

/*---------*/
/* Drucken */
/*---------*/

#define PRINT_END 0
#define PRINT_START 1
#define PRINT_FULLDOCUMENT 4
#define PRINT_INSERTDOCUMENT 5
#define PRINT_FULLDOCUMENTABORTDLG 7

/*--------------*/
/* Textfragment */
/*--------------*/

#define FRAGMENT_NONE        -1
#define FRAGMENT_TEXT         0
#define FRAGMENT_FORMFEED     1
#define FRAGMENT_LINEFEED     2
#define FRAGMENT_TAB          3
#define FRAGMENT_BITMAP       4
#define FRAGMENT_PF           6
#define FRAGMENT_BMPSCALE     8
#define FRAGMENT_METAFILE     9
#define FRAGMENT_BMPKEEPRATIO 10
#define FRAGMENT_MFSCALE      11
#define FRAGMENT_MFKEEPRATIO  12
#define FRAGMENT_TABLE		  14

/*-----------------------------*/
/* Flags fuer den Style (BYTE) */
/*-----------------------------*/

#define ATTR_STANDARD      0
#define ATTR_BOLD          1
#define ATTR_UNDERLINE     2
#define ATTR_ITALIC        4
#define ATTR_STRIKEOUT     8
#define ATTR_SUBSCRIPT    16
#define ATTR_SUPERSCRIPT  32

#define CURRENT_ATTRIBUTE 255   /* kann durch Kombination nicht auftreten,  */
                                /* da SUBSCRIPT und SUPERSCRIPT sich        */
                                /* ausschlieen                             */

/*-----------*/
/* Font Mode */
/*-----------*/

#define FONT_TYP 0x0F

#define FONT_DISPLAY 0x00
#define FONT_PRINTER 0x01
#define FONT_LOGICAL 0x02

#define FONT_SET 0xF0

#define FONT_SET_NONE   0x00
#define FONT_SET_STYLE  0x10
#define FONT_SET_COLOR  0x20
#define FONT_SET_NAME   0x40
#define FONT_SET_SIZE   0x80

#define FONT_SET_ALL (FONT_SET_STYLE | FONT_SET_COLOR | FONT_SET_NAME | FONT_SET_SIZE)

/*--------------*/
/* Protekttypen */
/*--------------*/

#define TYP_TEXT         0
#define TYP_BITMAP       6
#define TYP_USER        10

/*--------------*/
/* Schriftfarbe */
/*--------------*/

#define RGB_BLACK       0x00000000L
#define RGB_BLUE        0x00FF0000L
#define RGB_CYAN        0x00FFFF00L
#define RGB_GREEN       0x0000FF00L
#define RGB_MAGENTA     0x00FF00FFL
#define RGB_RED         0x000000FFL
#define RGB_YELLOW      0x0000FFFFL
#define RGB_WHITE       0x00FFFFFFL

#define RGB_DKBLUE      0x007F0000L
#define RGB_DKCYAN      0x007F7F00L
#define RGB_DKGREEN     0x00007F00L
#define RGB_DKMAGENTA   0x007F007FL
#define RGB_DKRED       0x0000007FL
#define RGB_DKYELLOW    0x00007F7FL

#define RGB_GRAY        0x007F7F7FL
#define RGB_LTGRAY      0x00C0C0C0L

#define CURRENT_COLOR   0xFFFFFFFFL

/*-----------------*/
/* Flags fr Zeile */
/*-----------------*/

#define ALIGN_MASK        0x0003

#define ALIGN_LEFT          0
#define ALIGN_RIGHT         1
#define ALIGN_CENTER        2
#define ALIGN_JUSTIFY       3

#define LINE_VISIBLE      0x0004
#define LINE_SOFTRETURN   0x0008
#define LINE_HARDRETURN   0x0010
#define LINE_FORMFEED     0x0020
#define LINE_TABULATOR    0x0080

#define SPACING_MASK      0x0300
#define SPACING_SHIFT	  8

#define SPACING_ONE         0
#define SPACING_ONEHALF     1
#define SPACING_DOUBLE      2

#define LINE_INVISIBLEPF  0x0400
#define LINE_PAGINATEFF   0x0800
#define LINE_NOTEDITABLE  0x1000

/*-----------------------*/
/* Flags fr Statuszeile */
/*-----------------------*/

#define STATUS_INFO          0
#define STATUS_X             1
#define STATUS_Y             2
#define STATUS_PAGE          3

#define STATUS_ELEMENT_COUNT 4

/*------------------*/
/* Flags fr Search */
/*------------------*/

#define SEARCH_FORWARD      0   // Vorwrtssuche wenn SEARCH_BACK nicht gesetzt
                                // deshalb kein Bit odieren
#define SEARCH_CASE         2
#define SEARCH_WORD         4
#define SEARCH_CURSOR       8
#define SEARCH_BACK        16
#define SEARCH_INIT        32

/*-------------------*/
/* Return von Search */
/*-------------------*/

#define SEARCH_NOTFOUND     0
#define SEARCH_FOUND        1
#define SEARCH_ERROR        2

/*---------------------*/
/* Flags fr HE_NEXTPF */
/*---------------------*/

#define NEXTPF_BACKWARD       0
#define NEXTPF_FORWARD        1
#define NEXTPF_ONLYEDITABLE   2
#define NEXTPF_ONLYVISIBLE   16
#define NEXTPF_FILEENDSTOP   32

/*-------------------------*/
/* Flags fr Protektfelder */
/*-------------------------*/

#define PF_ALIGNMASK     3

#define PF_ALIGNLEFT     0
#define PF_ALIGNRIGHT    1

#define PF_EDITABLE      4
#define PF_FUNCTION      8
#define PF_VISIBLE      32
#define PF_LINEREMOVE   64
#define PF_FIXEDSIZE   128
#define PF_MULTILINE   256

/*------------------------*/
/* Koordinate fr Bitmaps */
/*------------------------*/

#define BMP_ERROR       0x80008000

/*-------------------*/
/* Flags fr Bitmaps */
/*-------------------*/

#define BMP_NONE       -1
#define BMP_ORIGINAL    0
#define BMP_SCALE       1
#define BMP_KEEPRATIO   2

/*-------------------*/
/* Index von DocInfo */
/*-------------------*/

#define DOCINFO_TITLE        0
#define DOCINFO_SUBJECT      1
#define DOCINFO_OPERATOR     2
#define DOCINFO_AUTHOR       3
#define DOCINFO_KEYWORDS     4
#define DOCINFO_COMMENT      5

#define DOCINFO_CREATETIME   6
#define DOCINFO_REVISIONTIME 7
#define DOCINFO_PRINTTIME    8

#define DOCINFO_FIRSTTIME    6
#define DOCINFO_LASTTIME     8

/*-----------*/
/* Einheiten */
/*-----------*/

#define UNIT_CM     2540
#define UNIT_IN     1000

/*-------*/
/* Laden */
/*-------*/

#define LOAD_NORMAL         0
#define LOAD_SHAREDMEM     32
#define LOAD_NOSHAREDMEM   64

/*----------------------------------------*/
/* Von HighEdit zurckgesendete Meldungen */
/*----------------------------------------*/

/*--------*/
/* Fehler */
/*--------*/

#define HEF_LOWMEMORY           1
#define HEF_NOBLOCKMARK         2
#define HEF_NOHEFILE            3
#define HEF_NOLOAD              4
#define HEF_NOMEMORY            5
#define HEF_NOSAVE              6
#define HEF_NOSTART             7
#define HEF_NOTMPCLOSE          8
#define HEF_NOTMPOPEN           9
#define HEF_NOTMPSPACE          10
#define HEF_NORTFFILE           11
#define HEF_WRONGVERSION        12
#define HEF_NOFONT              13
#define HEF_NOPRINTER           14
#define HEF_NOWRITEACCESS       15
#define HEF_LOWRESOURCES        16

/*----------------------*/
/* Allgemeine Meldungen */
/*----------------------*/

#define HEM_ALIGN               20
#define HEM_DBLCLK              22
#define HEM_ENDPF               24
#define HEM_FORMATPF            25
#define HEM_GETHSCROLLPOS       26
#define HEM_GETVSCROLLPOS       27
#define HEM_HSCROLL             28
#define HEM_INSERT              29
#define HEM_KILLFOCUS           30
#define HEM_MODIFYPF            32
#define HEM_SELECTPF            34
#define HEM_SETFOCUS            35
#define HEM_SETHSCROLLPOS       36
#define HEM_SETHSCROLLRANGE     37
#define HEM_SETVSCROLLRANGE     39
#define HEM_SETVSCROLLPOS       40
#define HEM_SPACING             42
#define HEM_STYLE               43
#define HEM_TABMODIFY           44
#define HEM_VSCROLL             46

// ab Version 1.04g

#define HEM_SIZEPF              41
#define HEM_CURSORPOS           49
#define HEM_MESSAGETEXT         50
#define HEM_FILEEXISTS          52

// ab Version 1.10

#define HEM_PRINTHEAD           47
#define HEM_PRINTFOOT           48

#define HEM_NEWPAGEFRAGMENT     57

#define HEM_FONT                60
#define HEM_FONTSIZE            61
#define HEM_INITNEW             62

// Notification fr Visual Basic
// in Verbindung mit HS_NOTIFY
// ab Version 1.12a

#define HEM_KEYDOWN             64
#define HEM_KEYUP               65
#define HEM_CHAR                66
#define HEM_SYSKEYDOWN          67
#define HEM_SYSKEYUP            68
#define HEM_SYSCHAR             69

#define HEM_LBUTTONDOWN         72
#define HEM_MBUTTONDOWN         73
#define HEM_RBUTTONDOWN         74
#define HEM_LBUTTONUP           75
#define HEM_MBUTTONUP           76
#define HEM_RBUTTONUP           77
#define HEM_LBUTTONDBLCLK       78
#define HEM_MBUTTONDBLCLK       79
#define HEM_RBUTTONDBLCLK       80
#define HEM_MOUSEMOVE           81
#define HEM_CLICK               82

#define HEM_INSERTPF            86

// ab Version 2.0

#define HEM_SELECTPICTURE       89
#define HEM_TABWIDTH            90

// ab Version 2.03

#define HEM_QUERYPROFILENAME	93

/*----------------------------------*/
/* Fr HighEdit bestimmte Meldungen */
/*----------------------------------*/

#define HE_APPENDANSI               (WM_USER+20)
#define HE_APPENDDATA               (WM_USER+21)
#define HE_APPENDOEM                (WM_USER+22)

#define HE_CHANGEFUNCTIONPF         (WM_USER+41)
#define HE_CURSOREND                (WM_USER+45)
#define HE_CURSORHOME               (WM_USER+46)
#define HE_COUNTTOKEN               (WM_USER+47)

#define HE_DELETEPF                 (WM_USER+50)
#define HE_DELETETAB                (WM_USER+51)

#define HE_FMTLINES                 (WM_USER+60)
#define HE_FORMAT                   (WM_USER+61)
#define HE_FORMFEED                 (WM_USER+62)

#define HE_GETALIGN                 (WM_USER+70)
#define HE_GETCHAR                  (WM_USER+71)
#define HE_GETCOLOR                 (WM_USER+72)
#define HE_GETCURSOR                (WM_USER+73)
#define HE_GETFONTHANDLE            (WM_USER+74)
#define HE_ISINSERTMODE             (WM_USER+75)

// Alter Name aus Kompatibilittsgrnden vorhanden
#define HE_GETINSERT                HE_ISINSERTMODE

#define HE_GETLINE                  (WM_USER+77)
#define HE_GETLINECOUNT             (WM_USER+78)

#define HE_GETPFDATA                (WM_USER+79)
#define HE_GETPFFLAGS               (WM_USER+80)
#define HE_GETSTYLE                 (WM_USER+81)
#define HE_GETTYP                   (WM_USER+82)
#define HE_GETHEADRECT              (WM_USER+83)
#define HE_GETFOOTRECT              (WM_USER+84)

#define HE_GETNOTIFYTABLIST         (WM_USER+85)
#define HE_GETNOTIFYPROTECTHANDLE   (WM_USER+88)
#define HE_GETNOTIFYPROTECTWIDTH    (WM_USER+90)
#define HE_GETNOTIFYSCROLLHEIGHT    (WM_USER+91)
#define HE_GETNOTIFYSCROLLWIDTH     (WM_USER+92)
#define HE_GETNOTIFYHSCROLLRANGE    (WM_USER+93)
#define HE_GETNOTIFYHSCROLLPOS      (WM_USER+94)
#define HE_GETNOTIFYVSCROLLRANGE    (WM_USER+95)
#define HE_GETNOTIFYVSCROLLPOS      (WM_USER+96)
#define HE_GETNOTIFYMESSAGETEXT     (WM_USER+97)
#define HE_GETNOTIFYMESSAGELEN      (WM_USER+98)

#define HE_GETPRINTERDC             (WM_USER+99)
#define HE_GETPAGE                  (WM_USER+100)
#define HE_GETPFDATALEN             (WM_USER+101)
#define HE_GETSELECTION             (WM_USER+102)
#define HE_GETSPACING               (WM_USER+103)
#define HE_GETSTRING                (WM_USER+104)
#define HE_GETFRAGMENT              (WM_USER+105)
#define HE_GETPRINTERTEXTHEIGHT     (WM_USER+106)
#define HE_GETTEXTSEL               (WM_USER+107)
#define HE_GETTEXTWIDTH             (WM_USER+108)

#define HE_INSERTFUNCTIONPF         (WM_USER+114)
#define HE_INSERTTAB                (WM_USER+117)

#define HE_LINELENGTH               (WM_USER+130)
#define HE_LOADANSI                 (WM_USER+131)
#define HE_LOADDATA                 (WM_USER+132)
#define HE_LOADOEM                  (WM_USER+133)
#define HE_LOCKFUNCTIONPF           (WM_USER+135)

#define HE_ISMODIFIED               (WM_USER+140)

// Alter Name aus Kompatibilittsgrnden vorhanden
#define HE_MODIFY                   HE_ISMODIFIED

#define HE_MOVETAB                  (WM_USER+141)
#define HE_MOVEMARGIN               (WM_USER+142)

#define HE_NEW                      (WM_USER+150)
#define HE_NEXTPF                   (WM_USER+151)

#define HE_PRINTDOCUMENT            (WM_USER+161)
#define HE_PRINTFRAGMENT            (WM_USER+162)

#define HE_QUICKREPLACE             (WM_USER+170)

#define HE_REPLACESEL               (WM_USER+184)

#define HE_SAVEANSI                 (WM_USER+190)
#define HE_SAVEDATA                 (WM_USER+191)
#define HE_SAVEOEM                  (WM_USER+192)
#define HE_SEARCH                   (WM_USER+194)
#define HE_SELECTALL                (WM_USER+195)
#define HE_SELECTWORD               (WM_USER+197)
#define HE_SETALIGN                 (WM_USER+198)
#define HE_SETALLPFFLAGS            (WM_USER+199)
#define HE_SETAUTOHSIZE             (WM_USER+200)
#define HE_SETCURSOR                (WM_USER+201)
#define HE_SETCRVISIBLE             (WM_USER+202)
#define HE_SETGRAYBK                (WM_USER+204)
#define HE_SETINSERT                (WM_USER+206)
#define HE_SETLEFTMARGIN            (WM_USER+207)
#define HE_SETLINEBREAK             (WM_USER+209)
#define HE_SETSPACING               (WM_USER+210)
#define HE_SETMOUSECURSOR           (WM_USER+212)
#define HE_SETOFFSET                (WM_USER+213)
#define HE_SETPFBKVISIBLE           (WM_USER+214)
#define HE_SETPFFUNCTIONVISIBLE     (WM_USER+215)
#define HE_SETPFFLAGS               (WM_USER+216)
#define HE_SETSCROLLPOS             (WM_USER+217)
#define HE_SETSELECTION             (WM_USER+218)
#define HE_SETSPACEVISIBLE          (WM_USER+219)
#define HE_SETSTYLE                 (WM_USER+220)
#define HE_SETTAB                   (WM_USER+221)
#define HE_SETTABVISIBLE            (WM_USER+222)
#define HE_SETTABWIDTH              (WM_USER+223)
#define HE_SETTEXTHEIGHT            (WM_USER+224)
#define HE_SETTEXTWIDTH             (WM_USER+225)
#define HE_SETTOPMARGIN             (WM_USER+226)
#define HE_SETHSCROLL               (WM_USER+227)
#define HE_SETVSCROLL               (WM_USER+228)
#define HE_STATUSLINE               (WM_USER+229)

#define HE_UNLOCKFUNCTIONPF         (WM_USER+240)

#define HE_GETTABWIDTH              (WM_USER+246)
#define HE_SETMARGINS               (WM_USER+247)
#define HE_GETMARGINS               (WM_USER+248)
#define HE_GETPHYSICALDIM           (WM_USER+249)
#define HE_SETTEXTDIM               (WM_USER+250)
#define HE_GETTEXTDIM               (WM_USER+251)
#define HE_COPYDATA                 (WM_USER+253)
#define HE_PASTEDATA                (WM_USER+254)
#define HE_CANCOPY                  (WM_USER+256)
#define HE_CANPASTE                 (WM_USER+257)
#define HE_GETPHYSICALMARGINS       (WM_USER+258)
#define HE_GETPRINTERDIM            (WM_USER+259)
#define HE_LOADRTF                  (WM_USER+263)
#define HE_APPENDRTF                (WM_USER+264)
#define HE_SAVERTF                  (WM_USER+265)
#define HE_WRITEPROFILE             (WM_USER+266)
#define HE_ISPFACTIVE               (WM_USER+267)
#define HE_CLOSEACTIVEPF            (WM_USER+268)
#define HE_SETPFGHOST               (WM_USER+269)
#define HE_SETMODIFIED              (WM_USER+270)

// ab Version 1.04h

#define HE_SETLINEGHOST             (WM_USER+271)
#define HE_ADDPFFLAGS               (WM_USER+272)
#define HE_CLEARPFFLAGS             (WM_USER+273)
#define HE_ADDALLPFFLAGS            (WM_USER+274)
#define HE_CLEARALLPFFLAGS          (WM_USER+275)
#define HE_EXTSETREDRAW             (WM_USER+277)
#define HE_GETPRINTERIC             (WM_USER+278)

// ab Version 1.05

#define HE_PAGINATE                 (WM_USER+279)
#define HE_ISLINEBREAK              (WM_USER+280)
#define HE_ISGRAYBK                 (WM_USER+281)
#define HE_ISPFBKVISIBLE            (WM_USER+282)
#define HE_ISTABVISIBLE             (WM_USER+283)
#define HE_ISCRVISIBLE              (WM_USER+284)
#define HE_ISSPACEVISIBLE           (WM_USER+285)
#define HE_ISPFFUNCTIONVISIBLE      (WM_USER+286)
#define HE_ISPFGHOST                (WM_USER+287)
#define HE_ISLINEGHOST              (WM_USER+288)
#define HE_GETNOTIFYNEWPAGEFRAGMENT (WM_USER+289)
#define HE_GETNOTIFYPROTECTLEN      (WM_USER+290)

// ab Version 1.10

#define HE_GETDOCINFO               (WM_USER+294)
#define HE_SETDOCINFO               (WM_USER+295)
#define HE_GETCOLORLOGFONT          (WM_USER+296)
#define HE_GETFONTINDEX             (WM_USER+297)
#define HE_SETCOLORLOGFONT          (WM_USER+298)
#define HE_GETRGB                   (WM_USER+299)
#define HE_ADDFUNCTIONPF            (WM_USER+300)

#define HE_SETUNIT                  (WM_USER+302)
#define HE_GETUNIT                  (WM_USER+303)
#define HE_SETREADONLY              (WM_USER+305)
#define HE_ISREADONLY               (WM_USER+306)

// Notification fr Visual Basic
// in Verbindung mit HS_NOTIFY
// ab Version 1.12a

#define HE_GETNOTIFYWPARAM          (WM_USER+317)
#define HE_GETNOTIFYLPARAM          (WM_USER+318)

// ab Version 1.12b

#define HE_GETNOTIFYRESOURCES       (WM_USER+321)

// ab Version 1.13

#define HE_ISFORMFEED               (WM_USER+310)
#define HE_INSERTFUNCTIONPFPARAM    (WM_USER+323)
#define HE_NEXTPFEXT                (WM_USER+324)
#define HE_SETALLPFFLAGSEXT         (WM_USER+325)
#define HE_ADDALLPFFLAGSEXT         (WM_USER+326)
#define HE_CLEARALLPFFLAGSEXT       (WM_USER+327)
#define HE_SETPFBKCOLOR             (WM_USER+331)
#define HE_GETPFBKCOLOR             (WM_USER+332)
#define HE_GETPRINTERLINEHEIGHT     (WM_USER+333)
#define HE_GETPRINTERCURSORHEIGHT   (WM_USER+334)
#define HE_GETEOFCHAR               (WM_USER+335)
#define HE_SETEOFCHAR               (WM_USER+336)

// ab Version 1.13b

#define HE_GETSELECTIONSTART        (WM_USER+338)

// ab Version 1.14

#define HE_SETRBMARGINS             (WM_USER+340)
#define HE_GETRBMARGINS             (WM_USER+341)
#define HE_GETPFWIDTH               (WM_USER+342)
#define HE_SETPFWIDTH               (WM_USER+343)
#define HE_SETALLPFWIDTH            (WM_USER+344)
#define HE_SETALLPFWIDTHEXT         (WM_USER+345)

// ab Version 1.15

#define HE_SETTEXTSELECTABLE        (WM_USER+352)
#define HE_ISTEXTSELECTABLE         (WM_USER+353)

// ab Version 1.20

#define HE_SETLINEEDITABLE          (WM_USER+313)
#define HE_ISLINEEDITABLE           (WM_USER+314)
#define HE_SETIGNOREEDITABLE        (WM_USER+362)
#define HE_ISIGNOREEDITABLE         (WM_USER+363)
#define HE_SETSELECTIONEDITABLE     (WM_USER+364)
#define HE_SETABORTDLG              (WM_USER+365)
#define HE_SETPAGECOUNTER           (WM_USER+366)
#define HE_GETTAB                   (WM_USER+367)

// ab Version 1.25

#define HE_SETCLEARDELETE           (WM_USER+383)
#define HE_ISCLEARDELETE            (WM_USER+384)

// ab Version 1.26

#define HE_SETPERCENTTHUMB          (WM_USER+386)
#define HE_ISPERCENTTHUMB           (WM_USER+387)

// ab Version 1.27

#define HE_GETFUNCTIONPFTYP         (WM_USER+388)
#define HE_GETFUNCTIONPFTABLECOUNT  (WM_USER+389)

// ab Version 2.00

#define HE_INSERTBITMAP             (WM_USER+110)
#define HE_LOADBITMAP               (WM_USER+368)
#define HE_LOADPCX                  (WM_USER+369)
#define HE_LOADGIF                  (WM_USER+370)
#define HE_LOADTIFF                 (WM_USER+371)
#define HE_LOADTARGA                (WM_USER+372)
#define HE_SETPICTUREFLAGS          (WM_USER+373)
#define HE_GETPICTUREFLAGS          (WM_USER+374)
#define HE_LOADWMF                  (WM_USER+390)
#define HE_SHOWHEADFOOT             (WM_USER+391)
#define HE_ISHEADFOOTVISIBLE        (WM_USER+392)
#define HE_SETCONTEXT               (WM_USER+393)
#define HE_GETCONTEXT               (WM_USER+394)
#define HE_SETPICTUREFRAME          (WM_USER+395)
#define HE_ISPICTUREFRAME           (WM_USER+396)
#define HE_GETSCROLLPOS             (WM_USER+397)
#define HE_GETHEADFOOTHWND          (WM_USER+398)
#define HE_SETPICTUREDIM            (WM_USER+399)
#define HE_SETPICTUREOFFSET         (WM_USER+400)
#define HE_GETPICTUREDIM            (WM_USER+401)
#define HE_GETPICTUREOFFSET         (WM_USER+402)
#define HE_ENABLESCREENFONTS        (WM_USER+403)
#define HE_ISSCREENFONTSENABLED     (WM_USER+404)
#define HE_ISSCREENFONT             (WM_USER+405)
#define HE_GETSCREENCOLORLOGFONT    (WM_USER+406)

// ab Version 2.03

#define HE_GETPRINTERLINEWIDTH		(WM_USER+427)

// ab Version 3.00

#define HE_PREVIEW					(WM_USER+160)
#define HE_ISPREVIEW				(WM_USER+304)
#define HE_UNDO 					(WM_USER+328)
#define HE_CANUNDO					(WM_USER+329)
#define HE_QUERYUNDOTYPE			(WM_USER+330)
#define HE_SETINSTANCEPRINTER		(WM_USER+407)
#define HE_GETINSTANCEPRINTER		(WM_USER+409)
#define HE_INSERTTABLE				(WM_USER+420)
#define HE_GETUNDODEPTH 			(WM_USER+424)
#define HE_SETUNDODEPTH 			(WM_USER+425)
#define HE_CLEARUNDOLIST			(WM_USER+426)
#define HE_COPYRTF					(WM_USER+429)
#define HE_PASTERTF 				(WM_USER+430)
#define HE_ISTABLEACTIVE			(WM_USER+432)
#define HE_CLOSEACTIVETABLE 		(WM_USER+433)
#define HE_INSERTTABLEROW			(WM_USER+434)
#define HE_DELETETABLEROW			(WM_USER+435)

/*-------*/
/* Typen */
/*-------*/

typedef struct
{
    RECT rect;          /* Bereich, in dem die Ausgabe erfolgen kann */
    BOOL bHidden;       /* FALSE Wert wird ausgegeben                */
    HFONT hfont;        /* Schrift, mit der die Ausgabe erfolgt      */
}
STATUSLINE;

typedef STATUSLINE FAR * LPSTATUSLINE;

typedef struct
{
    WORD wHeight;       // Bei logische Schrifthhe * 4
    LOGFONT lf;         // Druckerschrift
    DWORD   rgb;        // Schriftfarbe
}
COLORLOGFONT;

typedef COLORLOGFONT FAR * LPCOLORLOGFONT;

typedef struct stExtTabData
{
    LONG lPrinterOffset;    /* Position in Druckerpunkten    */
    LONG lUnitOffset;       /* Position in Zentimeter * 1000 */
    BYTE byTabTyp;          /* Typen gem TAB_xxxxx         */
    BYTE pad;
}
EXTTABDATA;

typedef EXTTABDATA NEAR * NPEXTTABDATA;
typedef EXTTABDATA FAR * LPEXTTABDATA;

typedef struct stTab
{
    BYTE byNumber;          /* Anzahl der nachfolgenden Tabulatoren */
    BYTE pad;
}
TAB;

typedef TAB FAR * LPTAB;

typedef struct stTextFragment
{
    BYTE byTyp;             /* Typen gem FRAGMENT_xxxxx               */
    BYTE byColor;           /* Index auf die Farbtabelle                */
    WORD wStyleTyp;         /* Typen gem TYP_xxxx (Felder, Text)      */
    int  iYOffset;          /* Zustzlicher Y-Offset in Druckerpunkten  */
    LONG lHeight;           /* Zeilenhhe in Druckerpunkten             */
    HDC  hdc;               /* Drucker-DC                               */
    RECT rc;                /* Clip-Rectangle                           */
    LONG x;                 /* X-Position in Druckerpunkten             */
    LONG y;                 /* Y-Position in Druckerpunkten             */
    LONG lWidth;            /* Weite in Druckerpunkten                  */
    LONG lInternalWidth;
    LONG lInternalHeight;
    LONG xInternalOffset;
    LONG yInternalOffset;
    LONG lMFWidth;          /* Originalweite bei FRAGMENT_METAFILE      */
    LONG lMFHeight;         /* Originalhhe  bei FRAGMENT_METAFILE      */
    LONG xMFOffset;         /* Original x-Start bei FRAGMENT_METAFILE   */
    LONG yMFOffset;         /* Original y-Start bei FRAGMENT_METAFILE   */
    HFONT hfont;            /* Schrift                                  */
    LPINT lpiDeltaX;        /* Weitentabelle der einzelnen Zeichen      */
    WORD wDataLen;          /* Anzahl der Zeichen                       */
}
TEXTFRAGMENT;

typedef TEXTFRAGMENT FAR *LPTEXTFRAGMENT;

typedef struct stPrintDocParam
{
    HDC hdc;
    RECT rc;
    HWND hwndHead;
    HWND hwndFoot;
    BOOL bDummy;
    WORD wStartPage;
    WORD wEndPage;
    WORD wPageCounter;
    LPSTR lpDocTitle;
}
PRINTDOCPARAM;

typedef PRINTDOCPARAM FAR *LPPRINTDOCPARAM;

typedef struct
{
    GLOBALHANDLE hInfo[9];
    LONG lDocVersion;
    LONG lProgVersion;
}
GETDOCINFO;

typedef GETDOCINFO FAR *LPGETDOCINFO;

typedef struct
{
    LPSTR lpInfo[6];    // Nur Texte knnen verndert werden, kein Datum/Zeit
}
SETDOCINFO;

typedef SETDOCINFO FAR *LPSETDOCINFO;

typedef struct
{
    WORD wTyp;
    WORD wFlags;
    LPSTR lpData;
}
INSERTFUNCTIONPFPARAM;

typedef INSERTFUNCTIONPFPARAM FAR *LPINSERTFUNCTIONPFPARAM;

typedef struct
{
    HDC hdc;                    // Drucker-DC
    HWND hwndAbort;             // Handle der Dialogbox
    HWND hwndTop;               // Handle der Applikation
    HWND hwndPage;              // Feld zur Seitenanzeige
    WORD wPageCounter;          // Seitenzhler
    LPSTR lpPage;               // Format-String fr Seitenzhler
    LPSTR lpDocTitle;           // Dokumenttitel
    ABORTPROC lpfnAbortProc;    // Abbrechen-Callback-Funktion
}
ABORTDLGPARAM;

typedef ABORTDLGPARAM FAR *LPABORTDLGPARAM;

typedef struct
{
    LONG lUnitOffset;
    LONG lPrinterOffset;
}
MOVETABPARAM;

typedef MOVETABPARAM FAR *LPMOVETABPARAM;

typedef struct
{
    LONG lUnitOffset;
    LONG lPrinterOffset;
    LONG lIndentOffset;
    BYTE byTyp;
    BYTE pad;
}
MOVEMARGINPARAM;

typedef MOVEMARGINPARAM FAR *LPMOVEMARGINPARAM;

/*--------*/
/* Makros */
/*--------*/

/* Ermittlung der Koordinaten aus einem Rckgabepuffer */

#define GETXPOS(a)    (LOWORD (*((LONG FAR *) (a))))
#define GETYPOS(a)    ((LONG) (*(((LONG FAR *) (a)) + 1)))

/* Gre einer Tabulatorliste mit n Tabulatoren */

#define EXTTABSIZE(n)   (sizeof (TAB) + (n) * sizeof (EXTTABDATA))

/*------------------*/
/* Exportfunktionen */
/*------------------*/

BOOL FAR PASCAL HighEditInit (HINSTANCE hInstance);
DWORD FAR PASCAL HighEditVersion (VOID);

#ifdef __cplusplus
}
#endif  // __cplusplus

#endif // _INC_HE100
