unit vplay;

{Copyright by Jan Dekkers CIS 72130,353. Feel free to use the code
and solvideo.dll in your NON commercial program. Should you distribute the
SOLVIDEO.DLL and use this pascal interface in a commercial program you must
contact me to negotiate a licence fee. Portions (the original C code where the
DLL is based on) are written by Kirk E. Barrett}


interface
uses
  WinTypes;


function vidIsAVIInstalled : bool;

{//------------------------------------------------------------------------
// Function returns TRUE if AVI is installed, or FALSE if AVI is not
// installed.
//------------------------------------------------------------------------}


function vidSetupVideo(fname : Pchar;
                       pwnd  : hwnd;
                       rect  : trect;
                       where : integer) : bool;

{//------------------------------------------------------------------------
// vidSetupVideo(LPSTR Filename, HWND ParentWindow, LPRECT Rect, int where);
//
// Filename:            Fully qualified name of AVI file.
// ParentWindow:        Window to play AVI into.
// Rect:                Location in parent window to play AVI into. The
//                      AVI playback is streched to fit the RECT.
// Where:                                       1= New Window, 0=Current Client wnd
//
// Function returns TRUE if the AVI is currently playing, or FALSE if
// there was an error. When the video is complete, a message will be sent
// to the parent window message handling procedure. The messages is
// VIDEO_COMPLETE, which is equivalent to MM_MCINOTIFY and is defined
// below.
//
// Call VidPlayVideo to start playing video clip!
//------------------------------------------------------------------------}


function vidPlayVideo(pwnd  : hwnd) : bool;

{//------------------------------------------------------------------------
// vidPlayVideo(HWND ParentWindow);
//
// ParentWindow:        Window to recieve callback (MCI) notifications.
//
//      Plays the video!
//------------------------------------------------------------------------}

function vidStopVideo : bool;

{//------------------------------------------------------------------------
// vidStopVideo(void)
//
// Stop playing video and shutdown. This function MUST be called prior to
// exiting your application. Failure to do so will crash the system!
//
//------------------------------------------------------------------------ }

function vidGetVerboseResult : integer;

{//------------------------------------------------------------------------
// vidGetVerboseResult();
//
// Many of the above functions return TRUE or FALSE. vidGetVerboseResult()
// returns a numerical result which may be used with mciGetError().
// mciGetError() will return the string equivalent of the error.
//------------------------------------------------------------------------}

function vidReplayVideo : bool;

{//------------------------------------------------------------------------
// vidReplayVideo();
//
// After calleding vidPlayVideo() and before calling vidStopVideo(), the
// user may wish to replay the sequence. vidReplayVideo() will do precisely
// that. The video is replayed in the same location in the same parent
// window, or in the window created by VidSetupVideo.
//
// TRUE is returned if the video is playing, FALSE if otherwise.
//------------------------------------------------------------------------}

function vidPauseVideo : bool;

{//------------------------------------------------------------------------
// vidPauseVideo(void)
//
// This function is used to pause the video at the current location, after
// which, a call to vidResumeVideo() or vidStopVideo() may be called.
//
// TRUE is returned if the video is paused, FALSE if continuing play.
//------------------------------------------------------------------------}

function vidResumeVideo : bool;

{//------------------------------------------------------------------------
// vidResumeVideo(void);
//
// Resumes playing a previously paused video session.
//
// TRUE is returned if the video has resumed playing, FALSE if the video
// remains paused or has stopped.
//------------------------------------------------------------------------}


function vidResizeVideo(pwnd  : hwnd;
                        rect  : trect) : bool;


{//------------------------------------------------------------------------
//
// int FAR PASCAL vidResizeVideo(HWND Parent, LPRECT rc)
//
// Resize Window During Playback - Send from Parent's WM_SIZE
//
//------------------------------------------------------------------------}

function vidRewindVideo : bool;

{//------------------------------------------------------------------------
//
// int FAR PASCAL vidRewindVideo()
//
// Rewind Video to start.
//
//------------------------------------------------------------------------ }

function vidToggleAudio : bool;

{//------------------------------------------------------------------------
//
// int FAR PASCAL vidToggleAudio()
//
//      Enable/Disable (Mute) audio during playback
//
//------------------------------------------------------------------------}

function vidConfigure : bool;

{//------------------------------------------------------------------------
//
// int FAR PASCAL vidConfigure()
//
// Brings up Standard MCI Video Configure box for playback options,
//  full screen/window, etc.   Can save settings as Default!
//
//------------------------------------------------------------------------}




implementation

function vidIsAVIInstalled;     external 'SOLVIDEO' index 2;
function vidPlayVideo;          external 'SOLVIDEO' index 3;
function vidSetupVideo;         external 'SOLVIDEO' index 4;
function vidStopVideo;          external 'SOLVIDEO' index 5;
function vidGetVerboseResult;   external 'SOLVIDEO' index 6;
function vidReplayVideo;        external 'SOLVIDEO' index 7;
function vidPauseVideo;         external 'SOLVIDEO' index 8;
function vidResumeVideo;        external 'SOLVIDEO' index 9;
function vidResizeVideo;        external 'SOLVIDEO' index 10;
function vidRewindVideo;        external 'SOLVIDEO' index 11;
function vidToggleAudio;        external 'SOLVIDEO' index 12;
function vidConfigure;          external 'SOLVIDEO' index 13;

end.
