'****************************************************************************
'
'  File     : WAVEMIX.BAS (derived from WAVEMIX.H,  1994 Microsoft Corp.)
'
'  Comments : This file contains data structures and constants needed to use
'             the Microsoft WaveMix Library in Visual Basic.  Converted
'             for use with VB by Rob McGregor, CIS 73122,3125.  Use freely.
'
'****************************************************************************

Option Explicit

' Flag values for MIXPLAYPARAMS
Global Const WMIX_QUEUEWAVE = &H0
Global Const WMIX_CLEARQUEUE = &H1
Global Const WMIX_USELRUCHANNEL = &H2
Global Const WMIX_HIGHPRIORITY = &H4
Global Const WMIX_WAIT = &H8

Type MIXPLAYPARAMS
  wSize       As Integer
  hMixSession As Integer
  iChannel    As Integer
  lpMixWave   As Long
  hWndNotify  As Integer
  dwFlags     As Long
  wLoops      As Integer ' &HFFFF means loop forever
End Type

Type WAVEMIXINFO
  wSize         As Integer
  bVersionMajor As String * 1
  bVersionMinor As String * 1
  szDate        As String * 12 ' Mmm dd yyyy
  dwFormats     As Long        ' see waveOutGetDevCaps (wavemix requires synchronous device)
End Type

' Flags for MIXCONFIG
Global Const WMIX_CONFIG_CHANNELS = &H1
Global Const WMIX_CONFIG_SAMPLINGRATE = &H2

Type MIXCONFIG
  wSize         As Integer
  dwFlags       As Long
  wChannels     As Integer
  wSamplingRate As Integer ' 11, 22, 44 -- 11=11025, 22=22050, 44=44100 Hz
End Type
'=======================
' Function declarations
'=======================
Declare Function WaveMixGetInfo% Lib "wavemix.dll" (lpWaveMixInfo As WAVEMIXINFO)

' Return same errors as waveOutOpen, waveOutWrite, and waveOutClose
Declare Function WaveMixInit% Lib "wavemix.dll" () ' returns hMixSession - you should keep it
                                                   ' and use for subsequent API calls

Declare Function WaveMixConfigureInit% Lib "wavemix.dll" (lpConfig As MIXCONFIG)
Declare Function WaveMixActivate% Lib "wavemix.dll" (ByVal hMixSession%, ByVal fActivate%)

' Flags for WaveMixOpenWave()
Global Const WMIX_FILE = &H1
Global Const WMIX_RESOURCE = &H2
Global Const WMIX_MEMORY = &H4

Declare Function WaveMixOpenWave& Lib "wavemix.dll" (ByVal hMixSession%, ByVal szWaveFilename$, ByVal hInst%, ByVal dwFlags&)

' Flags for WaveMixOpenChannel()
Global Const WMIX_OPENSINGLE = 0   ' open the single channel specified by iChannel
Global Const WMIX_OPENALL = 1      ' opens all the channels, iChannel ignored
Global Const WMIX_OPENCOUNT = 2    ' open iChannel Channels (eg. if iChannel = 4 will create channels 0-3)

Declare Function WaveMixOpenChannel% Lib "wavemix.dll" (ByVal hMixSession%, ByVal iChannel%, ByVal dwFlags&)
Declare Function WaveMixPlay% Lib "wavemix.dll" (lpMixPlayParams As MIXPLAYPARAMS)

' Flags for WaveMixFlushChannel() & WaveMixCloseChannel()
Global Const WMIX_ALL = &H1      ' stops sound on all the channels, iChannel ignored
Global Const WMIX_NOREMIX = &H2  ' prevents the currently submited blocks from being remixed to exclude new channel

Declare Function WaveMixFlushChannel% Lib "wavemix.dll" (ByVal hMixSession%, ByVal iChannel%, ByVal dwFlags&)
Declare Function WaveMixCloseChannel% Lib "wavemix.dll" (ByVal hMixSession%, ByVal iChannel%, ByVal dwFlags&)
Declare Function WaveMixFreeWave% Lib "wavemix.dll" (ByVal hMixSession%, ByVal lpMixWave&)
Declare Function WaveMixCloseSession% Lib "wavemix.dll" (ByVal hMixSession%)
Declare Sub WaveMixPump Lib "wavemix.dll" ()

' Sample Rate Constants for WAVEMIXINFO
Global Const WAVE_FORMAT_1M08 = &H1   ' 11.025 kHz, Mono,   8 bit
Global Const WAVE_FORMAT_1S08 = &H2   ' 11.025 kHz, Stereo, 8 bit
Global Const WAVE_FORMAT_1M16 = &H4   ' 11.025 kHz, Mono,   16 bit
Global Const WAVE_FORMAT_1S16 = &H8   ' 11.025 kHz, Stereo, 16 bit
Global Const WAVE_FORMAT_2M08 = &H10  ' 22.05  kHz, Mono,   8 bit
Global Const WAVE_FORMAT_2S08 = &H20  ' 22.05  kHz, Stereo, 8 bit
Global Const WAVE_FORMAT_2M16 = &H40  ' 22.05  kHz, Mono,   16 bit
Global Const WAVE_FORMAT_2S16 = &H80  ' 22.05  kHz, Stereo, 16 bit
Global Const WAVE_FORMAT_4M08 = &H100 ' 44.1   kHz, Mono,   8 bit
Global Const WAVE_FORMAT_4S08 = &H200 ' 44.1   kHz, Stereo, 8 bit
Global Const WAVE_FORMAT_4M16 = &H400 ' 44.1   kHz, Mono,   16 bit
Global Const WAVE_FORMAT_4S16 = &H800 ' 44.1   kHz, Stereo, 16 bit

' Wave & MMSys constants
Global Const MMSYSERR_BASE = 0
Global Const WAVERR_BASE = 32

Global Const MMSYSERR_INVALHANDLE = (MMSYSERR_BASE + 5)  ' device handle is invalid
Global Const MMSYSERR_BADDEVICEID = (MMSYSERR_BASE + 2)  ' device ID out of range
Global Const MMSYSERR_ALLOCATED = (MMSYSERR_BASE + 4)    ' device already allocated
Global Const MMSYSERR_NOMEM = (MMSYSERR_BASE + 7)        ' memory allocation error
Global Const MMSYSERR_ERROR = (MMSYSERR_BASE + 1)        ' unspecified error

Global Const WAVERR_BADFORMAT = (WAVERR_BASE + 0)        ' unsupported wave format
Global Const WAVERR_SYNC = (WAVERR_BASE + 3)             ' device is synchronous




Function GetWaveChannelError (iWaveErr%)
  Dim sMsg$

  ' Check possible error returns
  Select Case iWaveErr
    
    Case MMSYSERR_INVALHANDLE
      sMsg = "An invalid channel (i.e. > 7) was specified."
    
    Case MMSYSERR_BADDEVICEID
      sMsg = "Specified device ID is out of range."
    
    Case MMSYSERR_ALLOCATED
      sMsg = "Specified resource is already allocated or the channel has already been opened."
    
    Case MMSYSERR_NOMEM
      sMsg = "Unable to allocate or lock memory."
    
    Case WAVERR_BADFORMAT
      sMsg = "Attempted to open with an unsupported wave format."
    
    Case WAVERR_SYNC
      sMsg = "Attempted to open a synchronous driver without specifying the WAVE_ALLOWSYNC flag."
    
    Case MMSYSERR_ERROR
      sMsg = "An internal error has occured."

    Case Else
      sMsg = "An unidentified error has occured."

  End Select
  GetWaveChannelError = sMsg

End Function

